@@ -162,12 +162,12 @@ async def test_coroutine_function(tmp_path: Path) -> None:
     acquired = released = False
 
     class AioFileLock(BaseAsyncFileLock):
-        async def _acquire(self) -> None:  # type: ignore[override]
+        async def _acquire(self) -> None:  # ty: ignore[invalid-method-override]
             nonlocal acquired
             acquired = True
             self._context.lock_file_fd = 1
 
-        async def _release(self) -> None:  # type: ignore[override]
+        async def _release(self) -> None:  # ty: ignore[invalid-method-override]
             nonlocal released
             released = True
             self._context.lock_file_fd = None
@@ -268,3 +268,54 @@ async def test_release_nonzero_counter_exit(
     assert lock.is_locked
     assert not any("Attempting to release" in m for m in caplog.messages)
     await lock.release()
+
+
+@pytest.mark.parametrize("lock_type", [AsyncFileLock, AsyncSoftFileLock])
+@pytest.mark.asyncio
+async def test_cancel_check_triggers(lock_type: type[BaseAsyncFileLock], tmp_path: Path) -> None:
+    lock_path = tmp_path / "a"
+    lock_1 = lock_type(str(lock_path))
+    lock_2 = lock_type(str(lock_path))
+
+    await lock_1.acquire()
+
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."):
+        await lock_2.acquire(timeout=1, cancel_check=lambda: True)
+    assert not lock_2.is_locked
+    await lock_1.release()
+
+
+@pytest.mark.parametrize("lock_type", [AsyncFileLock, AsyncSoftFileLock])
+@pytest.mark.asyncio
+async def test_cancel_check_not_called_when_lock_available(lock_type: type[BaseAsyncFileLock], tmp_path: Path) -> None:
+    lock_path = tmp_path / "a"
+    lock = lock_type(str(lock_path))
+
+    called = False
+
+    def should_not_be_called() -> bool:
+        nonlocal called
+        called = True
+        return True
+
+    await lock.acquire(cancel_check=should_not_be_called)
+    assert lock.is_locked
+    assert not called
+    await lock.release()
+
+
+@pytest.mark.parametrize("lock_type", [AsyncFileLock, AsyncSoftFileLock])
+@pytest.mark.asyncio
+async def test_cancel_check_log_message(
+    lock_type: type[BaseAsyncFileLock], tmp_path: Path, caplog: pytest.LogCaptureFixture
+) -> None:
+    caplog.set_level(logging.DEBUG)
+    lock_path = tmp_path / "a"
+    lock_1 = lock_type(str(lock_path))
+    lock_2 = lock_type(str(lock_path))
+
+    await lock_1.acquire()
+    with pytest.raises(Timeout):
+        await lock_2.acquire(timeout=1, cancel_check=lambda: True)
+    assert any("Cancellation requested" in msg for msg in caplog.messages)
+    await lock_1.release()
