@@ -231,7 +231,7 @@ class ExThread(threading.Thread):
     def run(self) -> None:
         try:
             super().run()
-        except Exception:  # noqa: BLE001 # pragma: no cover
+        except Exception:  # pragma: no cover
             self.ex = sys.exc_info()  # pragma: no cover
 
     def join(self, timeout: float | None = None) -> None:
@@ -242,6 +242,12 @@ class ExThread(threading.Thread):
 
 @pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
 def test_threaded_shared_lock_obj(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
+    if sys.platform == "win32" and lock_type.__name__ == "SoftFileLock":
+        pytest.skip(
+            "SoftFileLock uses file-existence locking — on Windows, unlink can silently fail under heavy "
+            "thread contention (EACCES from antivirus/indexer), orphaning the lock file with no recovery path"
+        )
+
     # Runs 100 threads, which need the filelock. The lock must be acquired if at least one thread required it and
     # released, as soon as all threads stopped.
     lock_path = tmp_path / "a"
@@ -262,11 +268,12 @@ def test_threaded_shared_lock_obj(lock_type: type[BaseFileLock], tmp_path: Path)
 
 
 @pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
-@pytest.mark.skipif(hasattr(sys, "pypy_version_info") and sys.platform == "win32", reason="deadlocks randomly")
 def test_threaded_lock_different_lock_obj(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
+    if sys.platform == "win32" and (hasattr(sys, "pypy_version_info") or lock_type.__name__ == "SoftFileLock"):
+        pytest.skip("SoftFileLock on Windows has race conditions under heavy threading")
+
     # Runs multiple threads, which acquire the same lock file with a different FileLock object. When thread group 1
     # acquired the lock, thread group 2 must not hold their lock.
-
     def t_1() -> None:
         for _ in range(1000):
             with lock_1:
@@ -391,7 +398,7 @@ def test_default_timeout(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
     # test if the default timeout parameter works
     lock_path = tmp_path / "a"
     lock_1, lock_2 = lock_type(str(lock_path)), lock_type(str(lock_path), timeout=0.1)
-    assert lock_2.timeout == 0.1
+    assert lock_2.timeout == pytest.approx(0.1)
 
     # acquire lock 1
     lock_1.acquire()
@@ -497,6 +504,55 @@ def test_poll_intervall_deprecated(lock_type: type[BaseFileLock], tmp_path: Path
             pytest.fail("No warnings of stacklevel=2 matching.")
 
 
+@pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
+def test_default_poll_interval(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
+    lock_path = tmp_path / "a"
+    lock = lock_type(str(lock_path))
+    assert lock.poll_interval == pytest.approx(0.05)
+
+    lock_2 = lock_type(str(lock_path), poll_interval=0.1)
+    assert lock_2.poll_interval == pytest.approx(0.1)
+
+    lock_2.poll_interval = 0.2
+    assert lock_2.poll_interval == pytest.approx(0.2)
+
+
+@pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
+def test_poll_interval_used_by_context_manager(
+    lock_type: type[BaseFileLock], tmp_path: Path, mocker: MockerFixture
+) -> None:
+    lock_path = tmp_path / "a"
+    lock_1 = lock_type(str(lock_path))
+    lock_2 = lock_type(str(lock_path), timeout=0.2, poll_interval=0.05)
+
+    lock_1.acquire()
+    sleep_mock = mocker.patch("filelock._api.time.sleep")
+    with pytest.raises(Timeout):
+        lock_2.acquire()
+    sleep_mock.assert_called_with(0.05)
+
+    sleep_mock.reset_mock()
+    lock_2.poll_interval = 0.1
+    with pytest.raises(Timeout):
+        lock_2.acquire()
+    sleep_mock.assert_called_with(0.1)
+    lock_1.release()
+
+
+@pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
+def test_poll_interval_acquire_override(lock_type: type[BaseFileLock], tmp_path: Path, mocker: MockerFixture) -> None:
+    lock_path = tmp_path / "a"
+    lock_1 = lock_type(str(lock_path))
+    lock_2 = lock_type(str(lock_path), timeout=0.2, poll_interval=0.05)
+
+    lock_1.acquire()
+    sleep_mock = mocker.patch("filelock._api.time.sleep")
+    with pytest.raises(Timeout):
+        lock_2.acquire(poll_interval=0.15)
+    sleep_mock.assert_called_with(0.15)
+    lock_1.release()
+
+
 @pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
 def test_context_decorator(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
     lock_path = tmp_path / "a"
@@ -597,14 +653,17 @@ def test_wrong_platform(tmp_path: Path) -> None:
     with pytest.raises(NotImplementedError):
         lock.acquire()
     with pytest.raises(NotImplementedError):
-        lock._release()  # noqa: SLF001
+        lock._release()
 
 
 @pytest.mark.skipif(sys.platform == "win32", reason="flock not run on windows")
+@pytest.mark.filterwarnings("default::UserWarning")
 def test_flock_not_implemented_unix(tmp_path: Path, mocker: MockerFixture) -> None:
     mocker.patch("fcntl.flock", side_effect=OSError(ENOSYS, "mock error"))
-    with pytest.raises(NotImplementedError), FileLock(tmp_path / "a.lock"):
-        pass
+    lock = FileLock(tmp_path / "a.lock")
+    with lock:
+        assert lock.is_locked
+        assert isinstance(lock, SoftFileLock)
 
 
 def test_soft_errors(tmp_path: Path, mocker: MockerFixture) -> None:
@@ -747,8 +806,14 @@ def test_singleton_locks_are_distinct_per_lock_file(lock_type: type[BaseFileLock
 @pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
 def test_singleton_locks_must_be_initialized_with_the_same_args(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
     lock_path = tmp_path / "a"
-    args: dict[str, Any] = {"timeout": -1, "mode": 0o644, "thread_local": True, "blocking": True}
-    alternate_args: dict[str, Any] = {"timeout": 10, "mode": 0, "thread_local": False, "blocking": False}
+    args: dict[str, Any] = {"timeout": -1, "mode": 0o644, "thread_local": True, "blocking": True, "poll_interval": 0.05}
+    alternate_args: dict[str, Any] = {
+        "timeout": 10,
+        "mode": 0,
+        "thread_local": False,
+        "blocking": False,
+        "poll_interval": 0.1,
+    }
 
     lock = lock_type(str(lock_path), is_singleton=True, **args)
 
@@ -771,23 +836,23 @@ def test_singleton_locks_are_deleted_when_no_external_references_exist(
     lock_path = tmp_path / "a"
     lock = lock_type(str(lock_path), is_singleton=True)
 
-    assert lock_type._instances == {str(lock_path): lock}  # noqa: SLF001
+    assert lock_type._instances == {str(lock_path): lock}
     del lock
-    assert lock_type._instances == {}  # noqa: SLF001
+    assert lock_type._instances == {}
 
 
 @pytest.mark.skipif(hasattr(sys, "pypy_version_info"), reason="del() does not trigger GC in PyPy")
 @pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
 def test_singleton_instance_tracking_is_unique_per_subclass(lock_type: type[BaseFileLock]) -> None:
-    class Lock1(lock_type):  # type: ignore[valid-type, misc]
+    class Lock1(lock_type):  # ty: ignore[unsupported-base]
         pass
 
-    class Lock2(lock_type):  # type: ignore[valid-type, misc]
+    class Lock2(lock_type):  # ty: ignore[unsupported-base]
         pass
 
-    assert isinstance(Lock1._instances, WeakValueDictionary)  # noqa: SLF001
-    assert isinstance(Lock2._instances, WeakValueDictionary)  # noqa: SLF001
-    assert Lock1._instances is not Lock2._instances  # noqa: SLF001
+    assert isinstance(Lock1._instances, WeakValueDictionary)
+    assert isinstance(Lock2._instances, WeakValueDictionary)
+    assert Lock1._instances is not Lock2._instances
 
 
 def test_singleton_locks_when_inheriting_init_is_called_once(tmp_path: Path) -> None:
@@ -827,12 +892,264 @@ def test_file_lock_positional_argument(tmp_path: Path) -> None:
 def test_mtime_zero_exit_branch(
     lock_type: type[BaseFileLock], expected_exc: type[BaseException], tmp_path: Path
 ) -> None:
-    p = tmp_path / "z.lock"
-    p.touch()
-    Path(p).chmod(0o444)
-    os.utime(p, (0, 0))
+    lock_path = tmp_path / "z.lock"
+    lock_path.touch()
+    Path(lock_path).chmod(0o444)
+    os.utime(lock_path, (0, 0))
 
-    lock = lock_type(str(p))
+    lock = lock_type(str(lock_path))
 
     with pytest.raises(expected_exc):
         lock.acquire(timeout=0)
+
+
+@pytest.mark.parametrize(
+    "lock_type",
+    [
+        pytest.param(
+            FileLock, marks=pytest.mark.skipif(sys.platform == "win32", reason="Windows cannot unlink open files")
+        ),
+        SoftFileLock,
+    ],
+)
+def test_lock_file_removed_after_release(tmp_path: Path, lock_type: type[BaseFileLock]) -> None:
+    lock_path = tmp_path / "test.lock"
+    lock = lock_type(str(lock_path))
+    with lock:
+        assert lock_path.exists()
+    assert not lock_path.exists()
+
+
+@pytest.mark.skipif(sys.platform == "win32", reason="Unix flock semantics")
+def test_concurrent_acquire_release_removes_lock_file(tmp_path: Path) -> None:
+    lock_path = tmp_path / "test.lock"
+    errors: list[Exception] = []
+
+    def worker() -> None:
+        try:
+            for _ in range(20):
+                lock = FileLock(str(lock_path), is_singleton=False)
+                with lock:
+                    pass
+        except Exception as exc:
+            errors.append(exc)
+
+    threads = [threading.Thread(target=worker) for _ in range(4)]
+    for thread in threads:
+        thread.start()
+    for thread in threads:
+        thread.join(timeout=30)
+    assert not errors, errors
+    assert not lock_path.exists()
+
+
+@pytest.mark.skipif(sys.platform == "win32", reason="Unix flock semantics")
+def test_lock_acquired_after_release_unlinks(tmp_path: Path) -> None:
+    lock_path = tmp_path / "test.lock"
+    first = FileLock(str(lock_path), is_singleton=False)
+    second = FileLock(str(lock_path), is_singleton=False)
+
+    first.acquire()
+    assert lock_path.exists()
+    first.release()
+    assert not lock_path.exists()
+
+    second.acquire()
+    assert lock_path.exists()
+    second.release()
+    assert not lock_path.exists()
+
+
+@pytest.mark.skipif(sys.platform == "win32", reason="Unix flock semantics")
+def test_stale_inode_retry_on_unlinked_lock(tmp_path: Path, mocker: MockerFixture) -> None:
+    lock_path = tmp_path / "test.lock"
+    lock = FileLock(str(lock_path), is_singleton=False)
+
+    real_fstat = os.fstat
+    call_count = 0
+
+    def fstat_unlinked_once(fd: int) -> os.stat_result:
+        nonlocal call_count
+        call_count += 1
+        if call_count == 1:
+            Path(lock_path).unlink()
+            return real_fstat(fd)
+        return real_fstat(fd)
+
+    mocker.patch("os.fstat", side_effect=fstat_unlinked_once)
+    lock.acquire()
+    assert lock.is_locked
+    assert call_count == 2
+    lock.release()
+
+
+@pytest.mark.skipif(sys.platform == "win32", reason="Unix flock semantics")
+def test_permission_error_fallback_without_o_creat(tmp_path: Path, mocker: MockerFixture) -> None:
+    lock_path = tmp_path / "test.lock"
+    lock_path.touch()
+    lock = FileLock(str(lock_path), is_singleton=False)
+
+    real_open = os.open
+    call_count = 0
+
+    def open_no_creat(path: str, flags: int, mode: int = 0o777, *, dir_fd: int | None = None) -> int:
+        nonlocal call_count
+        call_count += 1
+        if call_count == 1 and flags & os.O_CREAT:
+            raise PermissionError(13, "Permission denied", path)
+        return real_open(path, flags, mode) if dir_fd is None else real_open(path, flags, mode, dir_fd=dir_fd)
+
+    mocker.patch("os.open", side_effect=open_no_creat)
+    lock.acquire()
+    assert lock.is_locked
+    assert call_count == 2
+    lock.release()
+
+
+@pytest.mark.skipif(sys.platform == "win32", reason="Unix flock semantics")
+def test_permission_error_propagates_when_file_missing(tmp_path: Path, mocker: MockerFixture) -> None:
+    lock_path = tmp_path / "test.lock"
+    lock = FileLock(str(lock_path), is_singleton=False)
+
+    real_open = os.open
+
+    def open_always_permission_error(path: str, flags: int, mode: int = 0o777, *, dir_fd: int | None = None) -> int:
+        if "test.lock" in path:
+            raise PermissionError(13, "Permission denied", path)
+        return real_open(path, flags, mode) if dir_fd is None else real_open(path, flags, mode, dir_fd=dir_fd)
+
+    mocker.patch("os.open", side_effect=open_always_permission_error)
+    with pytest.raises(PermissionError, match="Permission denied"):
+        lock.acquire(timeout=0)
+
+
+@pytest.mark.skipif(sys.platform == "win32", reason="Unix flock semantics")
+def test_sticky_bit_fallback_handles_concurrent_unlink(tmp_path: Path, mocker: MockerFixture) -> None:
+    lock_path = tmp_path / "test.lock"
+    lock_path.touch()
+    lock = FileLock(str(lock_path), is_singleton=False)
+
+    real_open = os.open
+    call_count = 0
+
+    def open_permission_then_unlink(path: str, flags: int, mode: int = 0o777, *, dir_fd: int | None = None) -> int:
+        nonlocal call_count
+        call_count += 1
+        if call_count == 1 and flags & os.O_CREAT and "test.lock" in path:
+            raise PermissionError(13, "Permission denied", path)
+        if call_count == 2 and not (flags & os.O_CREAT) and "test.lock" in path:
+            lock_path.unlink(missing_ok=True)
+            raise FileNotFoundError(2, "No such file or directory", path)
+        return real_open(path, flags, mode) if dir_fd is None else real_open(path, flags, mode, dir_fd=dir_fd)
+
+    mocker.patch("os.open", side_effect=open_permission_then_unlink)
+    lock.acquire()
+    assert lock.is_locked
+    assert call_count == 3
+    lock.release()
+
+
+@pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
+def test_cancel_check_triggers(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
+    lock_path = tmp_path / "a"
+    lock_1 = lock_type(str(lock_path))
+    lock_2 = lock_type(str(lock_path))
+
+    lock_1.acquire()
+
+    with pytest.raises(Timeout, match=r"The file lock '.*' could not be acquired."):
+        lock_2.acquire(timeout=1, cancel_check=lambda: True)
+    assert not lock_2.is_locked
+    lock_1.release()
+
+
+@pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
+def test_cancel_check_after_n_polls(lock_type: type[BaseFileLock], tmp_path: Path, mocker: MockerFixture) -> None:
+    lock_path = tmp_path / "a"
+    lock_1 = lock_type(str(lock_path))
+    lock_2 = lock_type(str(lock_path))
+
+    lock_1.acquire()
+
+    call_count = 0
+
+    def cancel_after_two() -> bool:
+        nonlocal call_count
+        call_count += 1
+        return call_count >= 2
+
+    mocker.patch("filelock._api.time.sleep")
+    with pytest.raises(Timeout):
+        lock_2.acquire(timeout=10, cancel_check=cancel_after_two)
+    assert call_count == 2
+    assert not lock_2.is_locked
+    lock_1.release()
+
+
+@pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
+def test_cancel_check_not_called_when_lock_available(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
+    lock_path = tmp_path / "a"
+    lock = lock_type(str(lock_path))
+
+    called = False
+
+    def should_not_be_called() -> bool:
+        nonlocal called
+        called = True
+        return True
+
+    lock.acquire(cancel_check=should_not_be_called)
+    assert lock.is_locked
+    assert not called
+    lock.release()
+
+
+@pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
+def test_cancel_check_false_allows_acquisition(lock_type: type[BaseFileLock], tmp_path: Path) -> None:
+    lock_path = tmp_path / "a"
+    lock = lock_type(str(lock_path))
+
+    lock.acquire(cancel_check=lambda: False)
+    assert lock.is_locked
+    lock.release()
+
+
+@pytest.mark.parametrize("lock_type", [FileLock, SoftFileLock])
+def test_cancel_check_log_message(
+    lock_type: type[BaseFileLock], tmp_path: Path, caplog: pytest.LogCaptureFixture
+) -> None:
+    caplog.set_level(logging.DEBUG)
+    lock_path = tmp_path / "a"
+    lock_1 = lock_type(str(lock_path))
+    lock_2 = lock_type(str(lock_path))
+
+    lock_1.acquire()
+    with pytest.raises(Timeout):
+        lock_2.acquire(timeout=1, cancel_check=lambda: True)
+    assert any("Cancellation requested" in msg for msg in caplog.messages)
+    lock_1.release()
+
+
+@pytest.mark.skipif(sys.platform == "win32", reason="unix-only test")
+def test_filenotfound_on_fuse_nfs_retries(tmp_path: Path, mocker: MockerFixture) -> None:
+    """FileNotFoundError from FUSE/NFS os.open(O_CREAT) race is handled by retry."""
+    lock_path = tmp_path / "test.lock"
+    lock = FileLock(str(lock_path), is_singleton=False)
+
+    real_open = os.open
+    call_count = 0
+
+    def open_enoent_then_succeed(path: str, flags: int, mode: int = 0o777, *, dir_fd: int | None = None) -> int:
+        nonlocal call_count
+        call_count += 1
+        # Simulate FUSE/NFS race: first call to os.open(O_CREAT) fails with ENOENT
+        if call_count == 1 and flags & os.O_CREAT and "test.lock" in path:
+            raise FileNotFoundError(2, "No such file or directory", path)
+        return real_open(path, flags, mode) if dir_fd is None else real_open(path, flags, mode, dir_fd=dir_fd)
+
+    mocker.patch("os.open", side_effect=open_enoent_then_succeed)
+    lock.acquire()
+    assert lock.is_locked
+    # First call failed with ENOENT, retry succeeded
+    assert call_count >= 2
+    lock.release()
